@@ -619,7 +619,7 @@ brasero_track_data_cfg_get_value (GtkTreeModel *model,
 		case BRASERO_DATA_TREE_MODEL_NAME:
 			g_value_init (value, G_TYPE_STRING);
 			if (node->is_exploring)
-				g_value_set_string (value, _("(loading ...)"));
+				g_value_set_string (value, _("(loading…)"));
 			else
 				g_value_set_string (value, _("Empty"));
 
@@ -718,7 +718,7 @@ brasero_track_data_cfg_get_value (GtkTreeModel *model,
 	case BRASERO_DATA_TREE_MODEL_MIME_DESC:
 		g_value_init (value, G_TYPE_STRING);
 		if (node->is_loading)
-			g_value_set_string (value, _("(loading ...)"));
+			g_value_set_string (value, _("(loading…)"));
 		else if (!node->is_file) {
 			gchar *description;
 
@@ -729,7 +729,7 @@ brasero_track_data_cfg_get_value (GtkTreeModel *model,
 		else if (node->is_imported)
 			g_value_set_string (value, _("Disc file"));
 		else if (!BRASERO_FILE_NODE_MIME (node))
-			g_value_set_string (value, _("(loading ...)"));
+			g_value_set_string (value, _("(loading…)"));
 		else {
 			gchar *description;
 
@@ -790,12 +790,12 @@ brasero_track_data_cfg_get_value (GtkTreeModel *model,
 	case BRASERO_DATA_TREE_MODEL_SIZE:
 		g_value_init (value, G_TYPE_STRING);
 		if (node->is_loading)
-			g_value_set_string (value, _("(loading ...)"));
+			g_value_set_string (value, _("(loading…)"));
 		else if (!node->is_file) {
 			guint nb_items;
 
 			if (node->is_exploring) {
-				g_value_set_string (value, _("(loading ...)"));
+				g_value_set_string (value, _("(loading…)"));
 				return;
 			}
 
@@ -1088,7 +1088,7 @@ brasero_track_data_cfg_drag_data_get (GtkTreeDragSource *drag_source,
 				      GtkTreePath *treepath,
 				      GtkSelectionData *selection_data)
 {
-	if (selection_data->target == gdk_atom_intern (BRASERO_DND_TARGET_DATA_TRACK_REFERENCE_LIST, TRUE)) {
+	if (gtk_selection_data_get_target (selection_data) == gdk_atom_intern (BRASERO_DND_TARGET_DATA_TRACK_REFERENCE_LIST, TRUE)) {
 		GtkTreeRowReference *reference;
 
 		reference = gtk_tree_row_reference_new (GTK_TREE_MODEL (drag_source), treepath);
@@ -1123,6 +1123,7 @@ brasero_track_data_cfg_drag_data_received (GtkTreeDragDest *drag_dest,
 	BraseroFileNode *node;
 	BraseroFileNode *parent;
 	GtkTreePath *dest_parent;
+	GdkAtom target;
 	BraseroTrackDataCfgPrivate *priv;
 
 	priv = BRASERO_TRACK_DATA_CFG_PRIVATE (drag_dest);
@@ -1142,14 +1143,15 @@ brasero_track_data_cfg_drag_data_received (GtkTreeDragDest *drag_dest,
 
 	gtk_tree_path_free (dest_parent);
 
+	target = gtk_selection_data_get_target (selection_data);
 	/* Received data: see where it comes from:
 	 * - from us, then that's a simple move
 	 * - from another widget then it's going to be URIS and we add
 	 *   them to the DataProject */
-	if (selection_data->target == gdk_atom_intern (BRASERO_DND_TARGET_DATA_TRACK_REFERENCE_LIST, TRUE)) {
+	if (target == gdk_atom_intern (BRASERO_DND_TARGET_DATA_TRACK_REFERENCE_LIST, TRUE)) {
 		GList *iter;
 
-		iter = (GList *) selection_data->data;
+		iter = (GList *) gtk_selection_data_get_data (selection_data);
 
 		/* That's us: move the row and its children. */
 		for (; iter; iter = iter->next) {
@@ -1170,7 +1172,7 @@ brasero_track_data_cfg_drag_data_received (GtkTreeDragDest *drag_dest,
 			brasero_data_project_move_node (BRASERO_DATA_PROJECT (priv->tree), node, parent);
 		}
 	}
-	else if (selection_data->target == gdk_atom_intern ("text/uri-list", TRUE)) {
+	else if (target == gdk_atom_intern ("text/uri-list", TRUE)) {
 		gint i;
 		gchar **uris;
 		gboolean success = FALSE;
@@ -1179,6 +1181,13 @@ brasero_track_data_cfg_drag_data_received (GtkTreeDragDest *drag_dest,
 		 * success is enough to return TRUE. */
 		success = FALSE;
 		uris = gtk_selection_data_get_uris (selection_data);
+		if (!uris) {
+			const guchar *selection_data_raw;
+
+			selection_data_raw = gtk_selection_data_get_data (selection_data);
+			uris = g_uri_list_extract_uris ((gchar *) selection_data_raw);
+		}
+
 		if (!uris)
 			return TRUE;
 
@@ -1205,13 +1214,16 @@ brasero_track_data_cfg_row_drop_possible (GtkTreeDragDest *drag_dest,
 					  GtkTreePath *dest_path,
 					  GtkSelectionData *selection_data)
 {
+	GdkAtom target;
+
+	target = gtk_selection_data_get_target (selection_data);
 	/* See if we are dropping to ourselves */
-	if (selection_data->target == gdk_atom_intern_static_string (BRASERO_DND_TARGET_DATA_TRACK_REFERENCE_LIST)) {
+	if (target == gdk_atom_intern_static_string (BRASERO_DND_TARGET_DATA_TRACK_REFERENCE_LIST)) {
 		GtkTreePath *dest_parent;
 		BraseroFileNode *parent;
 		GList *iter;
 
-		iter = (GList *) selection_data->data;
+		iter = (GList *) gtk_selection_data_get_data (selection_data);
 
 		/* make sure the parent is a directory.
 		 * NOTE: in this case dest_path is the exact path where it
@@ -1283,7 +1295,7 @@ brasero_track_data_cfg_row_drop_possible (GtkTreeDragDest *drag_dest,
 		gtk_tree_path_free (dest_parent);
 		return FALSE;
 	}
-	else if (selection_data->target == gdk_atom_intern_static_string ("text/uri-list"))
+	else if (target == gdk_atom_intern_static_string ("text/uri-list"))
 		return TRUE;
 
 	return FALSE;
@@ -1961,6 +1973,9 @@ brasero_track_data_cfg_remove (BraseroTrackDataCfg *track,
 		return FALSE;
 
 	node = brasero_track_data_cfg_path_to_node (track, treepath);
+	if (!node)
+		return FALSE;
+
 	brasero_data_project_remove_node (BRASERO_DATA_PROJECT (priv->tree), node);
 	return TRUE;
 }
@@ -2241,6 +2256,14 @@ brasero_track_data_cfg_set_source (BraseroTrackData *track,
 							    grafts,
 							    excluded);
 
+	/* Remember that we own the list grafts and excluded
+	 * so we have to free them ourselves. */
+	g_slist_foreach (grafts, (GFunc) brasero_graft_point_free, NULL);
+	g_slist_free (grafts);
+
+	g_slist_foreach (excluded, (GFunc) g_free, NULL);
+	g_slist_free (excluded);
+
 	if (!priv->loading)
 		return BRASERO_BURN_OK;
 
@@ -2370,7 +2393,7 @@ brasero_track_data_cfg_get_file_num (BraseroTrackData *track)
 	return stats->children;
 }
 
-static BraseroTrackDataType
+static BraseroBurnResult
 brasero_track_data_cfg_get_track_type (BraseroTrack *track,
 				       BraseroTrackType *type)
 {
@@ -2378,13 +2401,10 @@ brasero_track_data_cfg_get_track_type (BraseroTrack *track,
 
 	priv = BRASERO_TRACK_DATA_CFG_PRIVATE (track);
 
-	if (!type)
-		return BRASERO_TRACK_TYPE_DATA;
-
 	brasero_track_type_set_has_data (type);
 	brasero_track_type_set_data_fs (type, brasero_track_data_cfg_get_fs (BRASERO_TRACK_DATA (track)));
 
-	return BRASERO_TRACK_TYPE_DATA;
+	return BRASERO_BURN_OK;
 }
 
 static BraseroBurnResult
@@ -2406,10 +2426,9 @@ brasero_track_data_cfg_get_status (BraseroTrack *track,
 	 * yet in the project and therefore project will look empty */
 	if (brasero_data_vfs_is_active (BRASERO_DATA_VFS (priv->tree))) {
 		if (status)
-			brasero_status_set_not_ready (status,
-						      -1.0,
-						      _("Analysing files"));
-
+			brasero_status_set_running (status,
+						    -1.0,
+						    _("Analysing files"));
 		return BRASERO_BURN_NOT_READY;
 	}
 
@@ -2491,10 +2510,10 @@ brasero_track_data_cfg_image_uri_cb (BraseroDataVFS *vfs,
 	g_value_init (params, G_TYPE_STRING);
 	g_value_set_string (params, uri);
 
-	/* default to CANCEL */
+	/* default to OK (for addition) */
 	return_value.g_type = 0;
 	g_value_init (&return_value, G_TYPE_INT);
-	g_value_set_int (&return_value, BRASERO_BURN_CANCEL);
+	g_value_set_int (&return_value, BRASERO_BURN_OK);
 
 	g_signal_emitv (instance_and_params,
 			brasero_track_data_cfg_signals [IMAGE],
@@ -3017,6 +3036,29 @@ brasero_track_data_cfg_span_stop (BraseroTrackDataCfg *track)
 	brasero_data_project_span_stop (BRASERO_DATA_PROJECT (priv->tree));
 }
 
+/**
+ * brasero_track_data_cfg_span_max_space:
+ * @track: a #BraseroTrackDataCfg
+ *
+ * Returns the maximum required space (in sectors) 
+ * among all the possible spanned batches.
+ * This means that when burningto a media
+ * it will also be the minimum required
+ * space to burn all the contents in several
+ * batches.
+ *
+ * Return value: a #goffset.
+ **/
+
+goffset
+brasero_track_data_cfg_span_max_space (BraseroTrackDataCfg *track)
+{
+	BraseroTrackDataCfgPrivate *priv;
+
+	priv = BRASERO_TRACK_DATA_CFG_PRIVATE (track);
+	return brasero_data_project_get_max_space (BRASERO_DATA_PROJECT (priv->tree));
+}
+
 /**
  * This is to handle the icon for the image
  */
@@ -3370,59 +3412,12 @@ brasero_track_data_cfg_finalize (GObject *object)
 		 * so we better remove all signals.
 		 * When an image URI is detected it can happen
 		 * that we'll be destroyed. */
-		g_signal_handlers_disconnect_by_func (priv->tree,
-		                                      brasero_track_data_cfg_node_added,
-		                                      object);
-		g_signal_handlers_disconnect_by_func (priv->tree,
-		                                      brasero_track_data_cfg_node_changed,
-		                                      object);
-		g_signal_handlers_disconnect_by_func (priv->tree,
-		                                      brasero_track_data_cfg_node_removed,
-		                                      object);
-		g_signal_handlers_disconnect_by_func (priv->tree,
-		                                      brasero_track_data_cfg_node_reordered,
-		                                      object);
-		g_signal_handlers_disconnect_by_func (priv->tree,
-		                                      brasero_track_data_cfg_size_changed_cb,
-		                                      object);
-		g_signal_handlers_disconnect_by_func (priv->tree,
-		                                      brasero_track_data_cfg_session_available_cb,
-		                                      object);
-		g_signal_handlers_disconnect_by_func (priv->tree,
-		                                      brasero_track_data_cfg_session_loaded_cb,
-		                                      object);
-		g_signal_handlers_disconnect_by_func (priv->tree,
-		                                      brasero_track_data_cfg_project_loaded,
-		                                      object);
-		g_signal_handlers_disconnect_by_func (priv->tree,
-		                                      brasero_track_data_cfg_activity_changed,
-		                                      object);
-		g_signal_handlers_disconnect_by_func (priv->tree,
-		                                      brasero_track_data_cfg_deep_directory,
-		                                      object);
-		g_signal_handlers_disconnect_by_func (priv->tree,
-		                                      brasero_track_data_cfg_2G_file,
-		                                      object);
-		g_signal_handlers_disconnect_by_func (priv->tree,
-		                                      brasero_track_data_cfg_unreadable_uri_cb,
-		                                      object);
-		g_signal_handlers_disconnect_by_func (priv->tree,
-		                                      brasero_track_data_cfg_unknown_uri_cb,
-		                                      object);
-		g_signal_handlers_disconnect_by_func (priv->tree,
-		                                      brasero_track_data_cfg_recursive_uri_cb,
-		                                      object);
-		g_signal_handlers_disconnect_by_func (priv->tree,
-		                                      brasero_track_data_cfg_image_uri_cb,
-		                                      object);
-		g_signal_handlers_disconnect_by_func (priv->tree,
-		                                      brasero_track_data_cfg_virtual_sibling_cb,
-		                                      object);
-		g_signal_handlers_disconnect_by_func (priv->tree,
-		                                      brasero_track_data_cfg_name_collision_cb,
-		                                      object);
-		g_signal_handlers_disconnect_by_func (priv->tree,
-		                                      brasero_track_data_cfg_joliet_rename_cb,
+		g_signal_handlers_disconnect_matched (priv->tree,
+		                                      G_SIGNAL_MATCH_DATA,
+		                                      0,
+		                                      0,
+		                                      NULL,
+		                                      NULL,
 		                                      object);
 
 		g_object_unref (priv->tree);
