@@ -43,7 +43,6 @@
 static void brasero_search_entry_class_init (BraseroSearchEntryClass *klass);
 static void brasero_search_entry_init (BraseroSearchEntry *sp);
 static void brasero_search_entry_finalize (GObject *object);
-static void brasero_search_entry_destroy (GtkObject *gtk_object);
 
 struct BraseroSearchEntryPrivate {
 	GtkWidget *button;
@@ -120,11 +119,9 @@ static void
 brasero_search_entry_class_init (BraseroSearchEntryClass *klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
-	GtkObjectClass *gtk_object_class = GTK_OBJECT_CLASS (klass);
 
 	parent_class = g_type_class_peek_parent (klass);
 	object_class->finalize = brasero_search_entry_finalize;
-	gtk_object_class->destroy = brasero_search_entry_destroy;
 
 	brasero_search_entry_signals[ACTIVATED_SIGNAL] =
 	    g_signal_new ("activated", G_OBJECT_CLASS_TYPE (object_class),
@@ -205,8 +202,11 @@ brasero_search_entry_init (BraseroSearchEntry *obj)
 				    G_TYPE_STRING,
 				    G_TYPE_STRING);
 
-	obj->priv->combo = gtk_combo_box_entry_new_with_model (GTK_TREE_MODEL (store),
-							       BRASERO_SEARCH_ENTRY_DISPLAY_COL);
+	obj->priv->combo = g_object_new (GTK_TYPE_COMBO_BOX,
+                                         "has-entry", TRUE,
+                                         "model", store,
+                                         "entry-text-column", BRASERO_SEARCH_ENTRY_DISPLAY_COL,
+                                         NULL);
 	g_object_unref (store);
 	g_signal_connect (G_OBJECT (obj->priv->combo),
 			  "changed",
@@ -341,12 +341,6 @@ brasero_search_entry_init (BraseroSearchEntry *obj)
 	g_strfreev (value);
 }
 
-static void
-brasero_search_entry_destroy (GtkObject *gtk_object)
-{
-	GTK_OBJECT_CLASS (parent_class)->destroy (gtk_object);
-}
-
 static void
 brasero_search_entry_finalize (GObject *object)
 {
